@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import sys
+import typing
 import logging
 import argparse
 
@@ -116,7 +117,7 @@ def validate_backup_json(backup: t.JSONType) -> None:
 
 
 class CustomArgumentParser(argparse.ArgumentParser):
-    def parse_args(self, args: list[str] = None, namespace=None):
+    def parse_args(self, args: typing.Sequence[str] | None = None, namespace=None):
         args = super().parse_args(args, namespace)
 
         # Since we're running as a CLI tool, install our own log level and color logger
