@@ -24,7 +24,7 @@ class StoredDevice:
         return dataclasses.replace(self, **kwargs)
 
 
-def rotate(lst: typing.Sequence, n: int) -> typing.Sequence:
+def rotate(lst: list, n: int) -> list:
     return lst[n:] + lst[:n]
 
 
@@ -71,7 +71,7 @@ def iter_seed_candidates(
         yield count, tclk_seed
 
 
-async def read_tc_frame_counter(znp: ZNP, *, ext_pan_id: t.EUI64 = None) -> t.uint32_t:
+async def read_nwk_frame_counter(znp: ZNP, *, ext_pan_id: t.EUI64 = None) -> t.uint32_t:
     if ext_pan_id is None and znp.network_info is not None:
         ext_pan_id = znp.network_info.extended_pan_id
 
@@ -110,7 +110,7 @@ async def read_tc_frame_counter(znp: ZNP, *, ext_pan_id: t.EUI64 = None) -> t.ui
     return global_entry.FrameCounter
 
 
-async def write_tc_frame_counter(
+async def write_nwk_frame_counter(
     znp: ZNP, counter: t.uint32_t, *, ext_pan_id: t.EUI64 = None
 ) -> None:
     if znp.version == 1.2:
@@ -172,9 +172,9 @@ async def read_addr_manager_entries(znp: ZNP) -> typing.Sequence[t.AddrMgrEntry]
     return entries
 
 
-async def read_hashed_link_keys(
+async def read_hashed_link_keys(  # type:ignore[misc]
     znp: ZNP, tclk_seed: t.KeyData
-) -> typing.Iterable[zigpy.state.Key]:
+) -> typing.AsyncGenerator[zigpy.state.Key, None]:
     if znp.version >= 3.30:
         entries = znp.nvram.read_table(
             item_id=ExNvIds.TCLK_TABLE,
@@ -206,7 +206,7 @@ async def read_hashed_link_keys(
 
 async def read_unhashed_link_keys(
     znp: ZNP, addr_mgr_entries: typing.Sequence[t.AddrMgrEntry]
-) -> typing.Iterable[zigpy.state.Key]:
+) -> typing.AsyncGenerator[zigpy.state.Key, None]:
     if znp.version == 3.30:
         link_key_offset_base = 0x0000
         table = znp.nvram.read_table(
